@@ -1,3 +1,30 @@
+# -*- coding: utf-8 -*-
+"""日志消息处理 示例模块
+
+本日志功能拷贝并修改自 万花（我的世界指令IDE）
+
+引用协议：
+版权所有© 全体 万花 作者
+
+   Copyright 2022 all the developers of Kaleido
+
+   Licensed under the Apache License, Version 2.0 (the 'License');
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       https://www.apache.org/licenses/LICENSE-2.0
+继承协议：
+版权所有© 全体 万花项目 和 睿穆组织 作者
+
+   Copyright 2022-2023 all the developers of Kaleido and Trim Organization
+
+   Licensed under the Apache License, Version 2.0 (the 'License');
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       https://www.apache.org/licenses/LICENSE-2.0
+"""
+
 import TrimLog
 from TrimLog import object_constants
 from TrimLog import log__init__, logger
